Module blaxel.core.client.models.trigger_configuration
======================================================

Classes
-------

`TriggerConfiguration(authentication_type: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, path: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, retry: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, schedule: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, tasks: blaxel.core.client.types.Unset | list['TriggerConfigurationTask'] = <blaxel.core.client.types.Unset object>)`
:   Trigger configuration
    
    Attributes:
        authentication_type (Union[Unset, str]): The authentication type of the trigger
        path (Union[Unset, str]): The path of the trigger
        retry (Union[Unset, int]): The retry of the trigger
        schedule (Union[Unset, str]): The schedule of the trigger, cron expression * * * * *
        tasks (Union[Unset, list['TriggerConfigurationTask']]): The tasks configuration of the cronjob
    
    Method generated by attrs for class TriggerConfiguration.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `authentication_type`
    :

    `path`
    :

    `retry`
    :

    `schedule`
    :

    `tasks`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :